<?php

/**
* Template Name: RSS Feeds
*/


use USKit\Base\ViewModels\BasePage;
use Infomaker\Everyware\Base\Models\Page;
use Infomaker\Everyware\Twig\View;
use USKit\Base\ViewModels\Teaser;
use USKit\Base\ViewModels\BaseObject;
use USKit\Base\Parts\Concept;
use USKit\Base\Parts\NewsMLArticle;
use Infomaker\Everyware\Base\OpenContent\QueryBuilder;
use Infomaker\Everyware\Base\OpenContent\OpenContentProvider;

header('Content-Type: application/rss+xml; charset=utf-8');

if (isset($_GET['categoryId'])) {
	$categoryFilter = $_GET['categoryId'];
} else {
	$categoryFilter = NULL;
}

if (isset($_GET['pageType'])) {
	$pageType = $_GET['pageType'];
} else {
	$pageType = 'story';
}

if (isset($_GET['count'])) {
	$count = $_GET['count'];
} else {
	$count = 10;
}

$rssCategoryName = OpenContentProvider::setup( [
	'q'  => QueryBuilder::where('uuid', $categoryFilter)->buildQueryString(),
] );

$rssCategoryName->setPropertyMap( 'Concept' );

$rssCategoryData = array_map( function ( Concept $concept ) {
    $concept_teaser = new BaseObject( $concept );
	return $concept_teaser->getViewData();
}, $rssCategoryName->queryWithRequirements() );

foreach($rssCategoryData as $category) {
	$categoryName = $category['name'];
}

if ($pageType == 'gallery' ) {
	$rssArticles = OpenContentProvider::setup( [
		'q'						 => QueryBuilder::where('ConceptCategoryUuids', $categoryFilter )->andIfProperty('SubType', 'gallery' )->buildQueryString(),
		'contenttypes'           => [ 'Article' ],
		'sort.indexfield'        => 'Pubdate',
		'sort.Pubdate.ascending'  => true,
		'limit'                  => $count,
		'Status'				 => 'usable'
	] );
} elseif ($pageType == 'video') {
	$rssArticles = OpenContentProvider::setup( [
		'q'						 => QueryBuilder::where('ConceptCategoryUuids', $categoryFilter )->andIfProperty('SubType', 'video' )->buildQueryString(),
		'contenttypes'           => [ 'Article' ],
		'sort.indexfield'        => 'Pubdate',
		'sort.Pubdate.ascending'  => true,
		'limit'                  => $count,
		'Status'				 => 'usable'
	] );	
} else {
	$rssArticles = OpenContentProvider::setup( [
		'q'						 => QueryBuilder::where('ConceptCategoryUuids', $categoryFilter )->andIfNotProperty('SubType', 'video' )->andIfNotProperty('SubType', 'gallery' )->buildQueryString(),
		'contenttypes'           => [ 'Article' ],
		'sort.indexfield'        => 'Pubdate',
		'sort.Pubdate.ascending'  => true,
		'limit'                  => $count,
		'Status'				 => 'usable'
	] );
}

$rssArticles->setPropertyMap( 'Article' );

$rssArticlesData = array_map( function ( NewsMLArticle $article ) {
    $teaser = new Teaser( $article );
	return $teaser->getViewData();
}, $rssArticles->queryWithRequirements() );


$counter = 0;
$rss_images = [];
foreach ($rssArticlesData as $rss) {
		libxml_use_internal_errors(true);

		$bodyraw = $rss['bodyraw'];
		$bodyraw = preg_replace('/\{\"(.+?)\"\}/', '', $bodyraw);
		$bodyraw = preg_replace('/&(?!#?[a-z0-9]+;)/', '&amp;', $bodyraw);
		$xml=simplexml_load_string($bodyraw);

		if ($xml) {
			if ($pageType != 'gallery')  {
				foreach($xml->group->object as $image) {
					if ($image->links->link && $image->links->link->data->text) {
						$uuid = (string) $image->links->link->attributes()->uuid;
						$caption = (string) $image->links->link->data->text->asXML();
						$caption = strip_tags($caption);
						${"rss_images_$counter"}[] = array('uuid' => $uuid, 'caption' => $caption);
					}
				};
			}

			if ($pageType == 'video' || $pageType == 'story' ) {
				foreach($xml->group->object as $youtube) {
					if ($youtube->links->link) {
						$videolink = (string) $youtube->links->link->attributes()->url;
						if ($videolink) {
							${"video_link_$counter"}[] = array('url' => $videolink);
						}
					}
				};	
			}

			if ($pageType == 'gallery') {
				foreach($xml->group->object as $gallery) {
					if ($gallery->attributes()->type == 'x-im/imagegallery') {

						$uuidCounter = 0;
						$rss_gallery_images = [];

						foreach($gallery->links->link as $links) {
							if ($links->attributes()->uuid && $links->data->text) {
								$uuid = (string) $links->attributes()->uuid;
								$caption = (string) $links->data->text->asXML();
								$caption = strip_tags($caption);
								$rss_gallery_images[$uuidCounter] = array('uuid' => $uuid, 'caption' => $caption);
							}
							$uuidCounter++;	
						}
					}
				};
			}

			if ($pageType == 'video' || $pageType == 'story') { 
				if (isset(${"video_link_$counter"})) {
					$rssArticlesData[$counter]['videoData'] = ${"video_link_$counter"}; 
				}
				$rssArticlesData[$counter]['pageType'] = $pageType; 
			};

			if ($pageType == 'gallery') { 
				$rssArticlesData[$counter]['rss_gallery_image_data'] = $rss_gallery_images; 
				$rssArticlesData[$counter]['pageType'] = $pageType; 
			};

			if ($pageType != 'gallery')  {
				if (isset(${"rss_images_$counter"})) {
					$rssArticlesData[$counter]['rss_image_data'] = ${"rss_images_$counter"};
				}
			}
		}
	$counter++;
}

$image_endpoint_url = get_theme_mod('image_endpoint_url' );
if(count($rssArticlesData) > 0) {
	$articles = View::generate( '@base/feeds/feed-articles.twig', [
		'articles' => $rssArticlesData,
		'test' => 'test1',
		'image_endpoint_url' => $image_endpoint_url
	]);
}

View::render( '@base/feeds/rss-feed.twig', [
	'articles' => $articles,
	'categoryName' => $categoryName,
] );